% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gvp.r
\name{gvp}
\alias{gvp}
\title{Calculate Glucose Variability Percentage (GVP)}
\usage{
gvp(data)
}
\arguments{
\item{data}{DataFrame object with column names "id", "time", and "gl"}
}
\value{
A tibble object with two columns:
subject id and corresponding GVP value.
}
\description{
The function mad produces GVP values in a tibble object.
}
\details{
A tibble object with 1 row for each subject, a column for subject id and
a column for GVP values is returned. NA glucose values are
omitted from the calculation of the GVP.

GVP is calculated by dividing the total length of the line of the glucose trace
by the length of a perfectly flat trace. The formula for this is
\eqn{sqrt(diff^2+dt0^2)/(n*dt0)}, where diff is the change in
Blood Glucose measurements from one reading to the next,
dt0 is the time gap between measurements and n is the number of glucose readings
}
\examples{

data(example_data_1_subject)
gvp(example_data_1_subject)

data(example_data_5_subject)
gvp(example_data_5_subject)

}
\references{
Peyser et al. (2017) Glycemic Variability Percentage: A Novel Method for Assessing
Glycemic Variability from Continuous Glucose Monitor Data.
\emph{Diabetes Technol Ther} \strong{20}(1):6–16,
\doi{10.1089/dia.2017.0187}.
}
\author{
David Buchanan, Mary Martin
}
